@@ -7,7 +7,7 @@ use App::Cmd::Setup -app;
 
 # ABSTRACT: Module/App to build and test OTRS packages
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 
 1;
@@ -16,13 +16,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 OTRS::OPM::Maker - Module/App to build and test OTRS packages
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 DESCRIPTION
 
@@ -58,10 +60,6 @@ Currently under development:
 
 =over 4
 
-=item * remote_install
-
-Install the OPM file on any OTRS instance. That remote OTRS instance need an OTRS package installed (this is also under development)
-
 =item * dbtest
 
 Check if the C<DatabaseInstall> and C<DatabaseUninstall> sections in your .sopm files are valid. And it checks for SQL keywords.
@@ -70,11 +68,11 @@ Check if the C<DatabaseInstall> and C<DatabaseUninstall> sections in your .sopm
 
 =head1 AUTHOR
 
-Renee Baecker <module@renee-baecker.de>
+Renee Baecker <reneeb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Renee Baecker.
+This software is Copyright (c) 2015 by Renee Baecker.
 
 This is free software, licensed under:
 
