@@ -69,6 +69,7 @@ sub execute {
     if ( @not_found ) {
         print "Files listed in .sopm but not found on disk:\n",
             map{ "    - $_\n" }@not_found;
+        exit 1;
     }
     
     if ( %fs ) {
@@ -83,21 +84,23 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 OTRS::OPM::Maker::Command::filetest - check if filelist in .sopm includes the files on your disk
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 AUTHOR
 
-Renee Baecker <module@renee-baecker.de>
+Renee Baecker <reneeb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Renee Baecker.
+This software is Copyright (c) 2015 by Renee Baecker.
 
 This is free software, licensed under:
 
